module Academical

  module Api

    # A teacher in a school.
    class Teachers

      def initialize(client)
        @client = client
      end

      # Get a teacher given its ID
      #
      # '/teachers/:id' GET
      #
      # id - ID of the teacher
      def get(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/teachers/#{id}", body, options)
      end

      # Delete a teacher given its ID
      #
      # '/teachers/:id' DELETE
      #
      # id - ID of the teacher
      def delete(id, options = {})
        body = options.fetch(:body, {})

        @client.delete("/teachers/#{id}", body, options)
      end

      # Create a new teacher in Academical. You must provide all of the required values
      #
      # '/teachers/' POST
      #
      # name - Object with the name of the teacher
      # school_id - ID of the school which this teacher belongs to
      def create(name, school_id, options = {})
        body = options.fetch(:body, {})
        body[:name] = name
        body[:school_id] = school_id

        @client.post("/teachers/", body, options)
      end

      # Update a teacher in Academical. You must provide all of the required parameters
      #
      # '/teachers/:id' PUT
      #
      # id - ID of the teacher
      # name - Object with the name of the teacher
      # school_id - ID of the school which this teacher belongs to
      def update(id, name, school_id, options = {})
        body = options.fetch(:body, {})
        body[:id] = id
        body[:name] = name
        body[:school_id] = school_id

        @client.put("/teachers/#{id}", body, options)
      end

    end

  end

end
